<?php

namespace FiloBlu\Flow\Model;

/**
 * Class Map
 * @package FiloBlu\Flow\Model
 */
class Map
{
    /**
     * @var bool
     */
    public $initialized = false;

    /**
     * @var string
     */
    public $file = 'map.json';

    /**
     * @var array
     */
    protected $mappedData = [];

    /**
     * @var \Monolog\Logger
     */
    protected $_logger;

    /**
     * @var \Magento\Framework\App\ObjectManager
     */
    protected $_objectManager;

    /**
     * Map constructor.
     * @param \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider
     */
    public function __construct(
        \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider
    ) {
        $this->_logger = $loggerProvider->getLogger();
        $this->_objectManager = \Magento\Framework\App\ObjectManager::getInstance();
    }

    /**
     * @param $channel
     */
    public function load($channel)
    {

        $model_channel = $this->_objectManager->create(\FiloBlu\Flow\Model\Channel::class);
        $model_channel->load($channel, 'name');

        if ($model_channel) {

            try {
                $json_content = str_replace(["\n", "\t", "\r"], '', $model_channel->getData('data'));
                $mapped_config = json_decode($json_content, true);
                $this->mappedData = $mapped_config['map'];
                $this->initialized = true;
                $this->_logger->info('Config : Loaded map json file');
            } catch (\Exception $e) {
                $this->_logger->info('Config : Fail to load map json file');
            }
        } else {
            $this->_logger->info('Config : File for channel data not exist for json map');
        }

    }

    /**
     * @param $field
     * @return mixed|null
     */
    public function get($field)
    {
        if (isset($this->mappedData[$field])) {
            return $this->mappedData[$field];
        }
        return null;
    }

    /**
     * @return array
     */
    public function getFields()
    {
        return array_keys($this->mappedData);
    }

    /**
     * @return array
     */
    public function getFullMappedData()
    {
        return $this->mappedData;
    }

    /**
     * @param array $mappedData
     */
    public function setFullMappedData($mappedData)
    {
        $this->mappedData = $mappedData;
    }

    /**
     * @param $data
     * @return bool
     */
    public function checkData($data)
    {
        if (count($data) == count($this->mappedData)) {
            return true;
        }

        return false;
    }

}
