<?php

namespace FiloBlu\Flow\Model\System;

/**
 *
 */
class ProductAttributes
{

    /** @var \Magento\Framework\App\ObjectManager */
    protected $_objectManager;

    /**
     * ProductAttributes constructor.
     */
    public function __construct()
    {
        $this->_objectManager = \Magento\Framework\App\ObjectManager::getInstance();
    }

    /**
     * @return array
     */
    public function toOptionArray()
    {
        $options = [];
        $attributes = $this->getAttributesToCopy();
        $attributeGroups = array_unique($attributes->getColumnValues('attribute_group_name'));
        foreach ($attributeGroups as $attributeGroupName) {
            $groupedOptions = [];
            $groupAttributes = $attributes->getItemsByColumnValue('attribute_group_name', $attributeGroupName);
            foreach ($groupAttributes as $attribute) {
                $attributeLabel = $attribute->getFrontendLabel() ? $attribute->getFrontendLabel() : $attribute->getAttributeCode();
                $groupedOptions[] = array(
                    'label' => $attributeLabel,
                    'value' => $attribute->getAttributeCode()
                );
            }

            $options[] = array(
                'label' => $attributeGroupName,
                'value' => $groupedOptions
            );
        }

        return $options;
    }

    /**
     * @return mixed
     */
    public function getAttributesToCopy()
    {
        $excludedGroups = [
            'Prices',
            'Recurring Profile'
        ];

        $excludedAttributes = [
            'sku',
            'status',
            'visibility',
            'old_id',
// 			'url_key',
// 			'url_path',
            'has_options',
            'required_options',
            'options_container',
            'created_at',
            'updated_at',
            'category_ids'
        ];

        $excludedFrontendInputs = [
            'price',
            'image',
            'media_image',
            'gallery'
        ];

        $productEntityType = $this->_objectManager->create('Magento\Eav\Model\Entity\Type')->loadByCode(\Magento\Catalog\Model\Product::ENTITY);
        $attributes = $this->_objectManager->create('Magento\Eav\Model\ResourceModel\Entity\Attribute\Collection');

        $attributes->setEntityTypeFilter($productEntityType);
        $attributes->join(array('eea' => 'eav_entity_attribute'), 'main_table.attribute_id = eea.attribute_id',
            array('group_id' => 'eea.attribute_group_id'));
        $attributes->join(array('eeg' => 'eav_attribute_group'), 'eea.attribute_group_id = eeg.attribute_group_id',
            array('attribute_group_name' => 'eeg.attribute_group_name'));
        $attributes->addFieldToFilter('attribute_group_name', array("nin" => $excludedGroups));
        $attributes->addFieldToFilter('frontend_input', array("nin" => $excludedFrontendInputs));
        $attributes->addFieldToFilter('attribute_code', array("nin" => $excludedAttributes));
        $attributes->getSelect()->group('main_table.attribute_id');
        $attributes->getSelect()->order('attribute_group_name ASC');

        return $attributes;
    }

}